==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Start/Gui/Resources/translations/StartPage.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0">
<context>
    <name>StartPage</name>
    <message>
        <location filename="StartPage.py" line="25"/>
        <source>FreeCAD Start Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="26"/>
        <source>Start a new project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="27"/>
        <source>Recent Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="63"/>
        <source>Tutorials</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="32"/>
        <source>FreeCAD Homepage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="33"/>
        <source>Example projects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="34"/>
        <source>Schenkel STEP file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="35"/>
        <source>Load a PartDesign example</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="36"/>
        <source>Load a Drawing extraction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="37"/>
        <source>Load a Robot simulation example</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="38"/>
        <source>Projects from the Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="39"/>
        <source>Schenkel STEP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="40"/>
        <source>Complex Part</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="41"/>
        <source>Close this window after opening or creating a file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="42"/>
        <source>Don&apos;t show me this window again next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="43"/>
        <source>Designing parts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="44"/>
        <source>The &lt;b&gt;Part Design&lt;/b&gt; workbench is designed to create complex pieces based on constrained 2D sketches. Use it to draw 2D shapes, constrain some of their elements and extrude them to form 3D pieces.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="45"/>
        <source>Example workflow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="46"/>
        <source>Part Design</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="47"/>
        <source>Designing architectural elements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="48"/>
        <source>The &lt;b&gt;Architectural Design&lt;/b&gt; workbench is specially designed for working with architectural elements such as walls or windows. Start by drawing 2D shapes, and use them as guides to build architecutral objects.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="49"/>
        <source>Architectual Design</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="50"/>
        <source>Working with Meshes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="51"/>
        <source>The &lt;b&gt;Mesh Workbench&lt;/b&gt; is used to work with Mesh objects. Meshes are simpler 3D objects than Part objects, but they are often easier to import and export to/from other applications.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="52"/>
        <source>FreeCAD offers you several tools to convert between Mesh and Part objects.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="53"/>
        <source>Work with Meshes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="54"/>
        <source>The complete workbench</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="55"/>
        <source>FreeCAD Complete workbench</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="57"/>
        <source>file size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="58"/>
        <source>creation time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="59"/>
        <source>last modified:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="56"/>
        <source>populated with some of the most commonly used tools.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="28"/>
        <source>Latest videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="29"/>
        <source>Latest news</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="30"/>
        <source>On the web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="31"/>
        <source>This is the FreeCAD Homepage. Here you will be able to find a lot of information about FreeCAD, including tutorials, examples and user documentation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="60"/>
        <source>location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="61"/>
        <source>User manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="62"/>
        <source>http://sourceforge.net/apps/mediawiki/free-cad/index.php?title=Online_Help_Toc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="64"/>
        <source>Python resources</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="65"/>
        <source>File not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="66"/>
        <source>from &lt;a href=http://twitter.com/FreeCADNews&gt;@FreeCADNews&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="67"/>
        <source>The FreeCAD-tutorial blog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="68"/>
        <source>from &lt;a href=http://www.youtube.com/user/FreeCADNews?feature=mhee&gt;FreeCADNews channel&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="69"/>
        <source>This is the official user manual of FreeCAD, built, maintained and translated by the FreeCAD community.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="70"/>
        <source>The tutorials section on the FreeCAD website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="71"/>
        <source>The section of the FreeCAd website dedicate dto python scripting, with examples, explanations, and API commands.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="72"/>
        <source>A blog dedicated to teaching FreeCAD, maintained by members of the FreeCAD community</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="73"/>
        <source>Getting started</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="74"/>
        <source>The FreeCAD interface is divided in workbenches, which are sets of tools suited for a specific task. You can start with one of the workbenches in this list, or with the complete workbench, which presents you with some of the most used tools gathered from other workbenches. Click to read more about workbenches on the FreeCAD website.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="75"/>
        <source>http://sourceforge.net/apps/mediawiki/free-cad/index.php?title=Workbench_Concept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="76"/>
        <source>Ship Design</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="77"/>
        <source>Designing and calculating ships</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="78"/>
        <source>The &lt;b&gt;Ship Design&lt;/b&gt; module offers several tools to help ship designers to view, model and calculate profiles and other specific properties of ship hulls.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="79"/>
        <source>Load an Architectural example model</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Start/Gui/Resources/translations/StartPage.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0">
<context>
    <name>StartPage</name>
    <message>
        <location filename="StartPage.py" line="50"/>
        <source>FreeCAD Start Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="51"/>
        <source>Start a new project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="52"/>
        <source>Recent Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="88"/>
        <source>Tutorials</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="57"/>
        <source>FreeCAD Homepage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="58"/>
        <source>Example projects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="59"/>
        <source>Schenkel STEP file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="60"/>
        <source>Load a PartDesign example</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="61"/>
        <source>Load a Drawing extraction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="62"/>
        <source>Load a Robot simulation example</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="63"/>
        <source>Projects from the Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="64"/>
        <source>Schenkel STEP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="65"/>
        <source>Complex Part</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="66"/>
        <source>Close this window after opening or creating a file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="67"/>
        <source>Don&apos;t show me this window again next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="68"/>
        <source>Designing parts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="69"/>
        <source>The &lt;b&gt;Part Design&lt;/b&gt; workbench is designed to create complex pieces based on constrained 2D sketches. Use it to draw 2D shapes, constrain some of their elements and extrude them to form 3D pieces.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="70"/>
        <source>Example workflow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="71"/>
        <source>Part Design</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="72"/>
        <source>Designing architectural elements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="73"/>
        <source>The &lt;b&gt;Architectural Design&lt;/b&gt; workbench is specially designed for working with architectural elements such as walls or windows. Start by drawing 2D shapes, and use them as guides to build architecutral objects.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="74"/>
        <source>Architectual Design</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="75"/>
        <source>Working with Meshes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="76"/>
        <source>The &lt;b&gt;Mesh Workbench&lt;/b&gt; is used to work with Mesh objects. Meshes are simpler 3D objects than Part objects, but they are often easier to import and export to/from other applications.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="77"/>
        <source>FreeCAD offers you several tools to convert between Mesh and Part objects.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="78"/>
        <source>Work with Meshes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="79"/>
        <source>The complete workbench</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="80"/>
        <source>FreeCAD Complete workbench</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="82"/>
        <source>file size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="83"/>
        <source>creation time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="84"/>
        <source>last modified:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="81"/>
        <source>populated with some of the most commonly used tools.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="53"/>
        <source>Latest videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="54"/>
        <source>Latest news</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="55"/>
        <source>On the web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="56"/>
        <source>This is the FreeCAD Homepage. Here you will be able to find a lot of information about FreeCAD, including tutorials, examples and user documentation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="85"/>
        <source>location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="86"/>
        <source>User manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="89"/>
        <source>Python resources</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="90"/>
        <source>File not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="91"/>
        <source>from &lt;a href=http://twitter.com/FreeCADNews&gt;@FreeCADNews&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="92"/>
        <source>The FreeCAD-tutorial blog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="93"/>
        <source>from &lt;a href=http://www.youtube.com/user/FreeCADNews?feature=mhee&gt;FreeCADNews channel&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="94"/>
        <source>This is the official user manual of FreeCAD, built, maintained and translated by the FreeCAD community.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="95"/>
        <source>The tutorials section on the FreeCAD website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="96"/>
        <source>The section of the FreeCAd website dedicate dto python scripting, with examples, explanations, and API commands.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="97"/>
        <source>A blog dedicated to teaching FreeCAD, maintained by members of the FreeCAD community</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="98"/>
        <source>Getting started</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="99"/>
        <source>The FreeCAD interface is divided in workbenches, which are sets of tools suited for a specific task. You can start with one of the workbenches in this list, or with the complete workbench, which presents you with some of the most used tools gathered from other workbenches. Click to read more about workbenches on the FreeCAD website.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="101"/>
        <source>Ship Design</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="102"/>
        <source>Designing and calculating ships</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="103"/>
        <source>The &lt;b&gt;Ship Design&lt;/b&gt; module offers several tools to help ship designers to view, model and calculate profiles and other specific properties of ship hulls.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="104"/>
        <source>Load an Architectural example model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="87"/>
        <source>http://www.freecadweb.org/wiki/index.php?title=Online_Help_Toc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="100"/>
        <source>http://www.freecadweb.org/wiki/index.php?title=Workbench_Concept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="105"/>
        <source>http://www.freecadweb.org/wiki/index.php?title=Tutorials</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="StartPage.py" line="106"/>
        <source>http://www.freecadweb.org/wiki/index.php?title=Power_users_hub</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
